package
Version:
v0.2.0-beta.2
Opens a new window with list of versions in this module.
Published: Sep 15, 2025
License: AGPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Mat4 represents a 4x4 matrix in column-major order.
Identity returns an identity matrix.
func Orthographic(left, right, bottom, top, near, far float32) Mat4
Orthographic returns an orthographic projection matrix.
Perspective returns a perspective projection matrix.
Scale returns a scaling matrix for v.
Translation returns a matrix translating by v.
Mul multiplies m by n and returns the result.
Vec2 represents a 2D vector.
Add adds two vectors component-wise.
Normalize returns the unit vector in the same direction.
type Vec3 struct{ X, Y, Z float32 }
Vec3 represents a 3D vector.
Add adds two Vec3 values component-wise.
Normalize returns the unit vector of v.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.